@@ -936,6 +936,7 @@ class VariableClUpdateProfileCheckSyncAllowed(Variable):
     urls = 'cl_update_rep_url'
     names = 'cl_update_rep_name'
     path = 'cl_update_profile_path'
+    cache_path = 'cl_update_package_cache'
 
     def get(self):
         if not self.Get(self.urls) or not self.Get(self.names):
@@ -946,6 +947,10 @@ class VariableClUpdateProfileCheckSyncAllowed(Variable):
                 with open(f'{rep}/test', 'w') as inf:
                     inf.write("test")
                 quite_unlink(f"{rep}/test")
+            path = self.Get(self.cache_path)
+            with open(f'{rep}/test', 'w') as inf:
+                inf.write("test")
+            quite_unlink(f"{rep}/test")
         except OSError:
             return False
         return True
